ASAP-NMS: Accelerating Non-Maximum Suppression Using Spatially Aware Priors
The paper introduces ASAP-NMS, a faster version of the Non-Maximum Suppression algorithm that reduces processing time by focusing on nearby proposals using spatial priors, significantly improving speed without losing detection accuracy. This method acts as a simple, effective upgrade for object detection systems, making them more efficient during inference.
Abstract
The widely adopted sequential variant of Non Maximum Suppression (or Greedy-NMS) is a crucial module for object-detection pipelines. Unfortunately, for the region proposal stage of two/multi-stage detectors, NMS is turning out to be a latency bottleneck due to its sequential nature. In this article, we carefully profile Greedy-NMS iterations to find that a major chunk of computation is wasted in comparing proposals that are already far-away and have a small chance of suppressing each other. We address this issue by comparing only those proposals that are generated from nearby anchors. The translation-invariant property of the anchor lattice affords generation of a lookup table, which provides an efficient access to nearby proposals, during NMS. This leads to an Accelerated NMS algorithm which leverages Spatially Aware Priors, or ASAP-NMS, and improves the latency of the NMS step from 13.6ms to 1.2 ms on a CPU without sacrificing the accuracy of a state-of-the-art two-stage detector on COCO and VOC datasets. Importantly, ASAP-NMS is agnostic to image resolution and can be used as a simple drop-in module during inference. Using ASAP-NMS at run-time only, we obtain an mAP of 44.2\%@25Hz on the COCO dataset with a V100 GPU.
AI Key Findings
Get AI-generated insights about this paper's methodology, results, significance, and more — available when analysis has been generated.
Discussion 0